# SimNDT2b

The batch processor version of SimNDT Version 2

The batch processor reads the entire simulation scenario from a json file and performs a simulation. Output can be saved in numpy format by enabling snapshots.
Either each snapshot step is svaed in one file, or the snapshots (matrix of specific field variables) are accumulated in a three-dimensional volume, saved in on numpy file.

## Authors

1. Miguel Molero (original SimNDT)
2. Stefan Bosse (SimNDT2 and SimNDT2b)
3. Sanjeev Kumar (SimNDT2b)

## Prerequisits

```
python2
cffi==1.14.5
Cython==0.29.22
matplotlib==2.0.0
numpy==1.16.6
opencv-python==3.4.9.31
Pillow==6.2.2
pyopencl==2019.1.2
PyOpenGL==3.1.0
PySide==1.2.2
pytools==2019.1.1
scipy==1.2.3
jsonpickle==2.2.0
```

## Batch processing run

1. Update the path to save the simulation data in the JOSN file under the key name ["Snapshot"]["Save_filepath"] (or ["Export"]["Save_filepath"]).
2. Run and save simulation command: python main.py "path_to_json_file"


```
python2 $TOP/src/main.py ParamJSON/simndt_paramas_alu_hole_20mm.json 
```


## JSON Format

### Import

#### Material

- `Im:<path-to-2dim-numpy-file>` (front-end)
- `Iabs:<path-to-2dim-numpy-file>` (front-end)
- `Rho:<path-to-2dim-numpy-file>` and `VL:<path-to-2dim-numpy-file>` and `VT:<path-to-2dim-numpy-file>` containing Rho, VL, and VT matrix (back-end, engine)

```
  "Import": {
     "Im": "/tmp/simulation-materials-Im.npy"
  }
  "Import": {
     "Rho": "/tmp/simulation-materials-Rho.npy",
     "VL": "/tmp/simulation-materials-VL.npy",
     "VT": "/tmp/simulation-materials-VT.npy"
  }
```

### Export

#### Material

Exports material matrix 

`enableMaterial:true,Material:XX`

- Iabs: Material label matrix w/o boundaries, front-end
- Im: Material label matrix with boundaries (same size as field matrix), front-end
- RV: Rho,VT,VL material matrix set, back-end (engine)
- RC: Rho,C11,.. material matrix set, back-end (engine)

`enableSignals:true,Field:XX`

- Export sensor signals (derived from Field XX)

Fields: "Vx","Vy","[Vx,Vy]","Txx","Txy","Tyy","[Txx:Txy:Tyy]","Dx","Dy","[Dx,Dy]","SV"

```
  "Export": {
    "Step": 100,
    "Save_filepath": "/tmp/",
    "Filename": "simulation",
    "Extension": ".png",
    "dB": 60,
    "Color": 0,
    "Field": "Txx",
    "Material": "RV",
    "enableFields": false,
    "enableNumPy": true,
    "enableSignals": true,
    "enableImages": false,
    "enableMaterial": true,
    "enableVolume": true,
    "enableView": false,
    "sensorShape": [],
    "sensorPlacement": [],
    "sensorSize": 0
  }
```

